@@ -25,3 +25,17 @@
 
 (initializer_list
   (_) @entry.outer)
+
+;; Additional queries
+
+(for_statement
+ body: (_) @loop.inner) @loop.outer
+
+(while_statement
+ body: (_) @loop.inner) @loop.outer
+
+(do_statement
+ body: (_) @loop.inner) @loop.outer
+
+(if_statement
+ consequence: (_) @conditional.inner) @conditional.outer
\ No newline at end of file
