@@ -11,8 +11,8 @@
 (type_declaration
   (type_spec (type_identifier) (struct_type (field_declaration_list (_)?) @class.inner))) @class.outer
 
-;; (type_declaration
-;;   (type_spec (type_identifier) (interface_type (method_spec)+ @class.inner))) @class.outer
+(type_declaration
+  (type_spec (type_identifier) (interface_type (method_elem)+ @class.inner))) @class.outer
 
 (type_parameter_list
   ((_) @parameter.inner . ","? @parameter.outer) @parameter.outer)
@@ -31,3 +31,23 @@
    name: (identifier) @_name
    body: (block)? @test.inner) @test.outer
  (#match "^Test" @_name))
+
+;; Additional queries
+
+(if_statement
+  consequence: (block) @conditional.inner) @conditional.outer
+
+(if_statement
+  alternative: (block) @conditional.inner)? @conditional.outer
+
+(expression_switch_statement
+  (expression_case) @conditional.inner) @conditional.outer
+
+(type_switch_statement
+  (type_case) @conditional.inner) @conditional.outer
+
+(select_statement
+  (communication_case) @conditional.inner) @conditional.outer
+
+(for_statement
+  body: (block) @loop.inner) @loop.outer
\ No newline at end of file
