@@ -33,3 +33,14 @@
 
 (pair
   (_) @entry.inner) @entry.outer
+
+;; Additional queries
+
+(for_statement
+ body: (_) @loop.inner) @loop.outer
+
+(while_statement
+ body: (_) @loop.inner) @loop.outer
+
+(if_statement
+ consequence: (_) @conditional.inner) @conditional.outer
\ No newline at end of file
